#!/usr/bin/env python2
#!-*- coding: utf-8 -*-
# Thurs Jun 2015

import datetime
import random
import string
import sys

__version__ = '0.1.0'
__doc__ = '''Learn to type 10 fingers'''


def run(length):
    count = 0
    while True:
        print "string pattern:"
        str_pattern = ''.join(random.choice(string.printable + ' ')
                              for i in range(int(length)))
        print str_pattern
        starttime = datetime.datetime.now()
        your_str = raw_input("Enter your string in 3 seconds (press Ctrl +" +
                             "C to exit):\n")
        endtime = datetime.datetime.now()
        yourtime = endtime - starttime

        print "spent %s seconds" % yourtime.total_seconds()

        if yourtime.total_seconds() > 3:
            print "so slow, need to learn more"
            sys.exit(1)

        if your_str == str_pattern:
            count = count + 1
            print "You are great."
            print count
            print "-------------------------------------------------------"
            if count == 30:
                print "Congratulation, going to next level"
                count = 0
                length = length + 1
                run(length)
            continue
        else:
            print "Wrong, you need to train more!"
            sys.exit(2)

if __name__ == '__main__':
    run(4)



import argparse

import flyfingers


def parse_args():
    parser = argparse.ArgumentParser(description=flyfingers.__doc__)
    sparsers = parser.add_subparsers(dest='subparser_name')
    sub_parser = sparsers.add_parser('run', help='start flyfingers')
    sub_parser.add_argument('run')
    sub_parser.set_defaults(func=getattr(flyfingers, 'run'))
    args = parser.parse_args()

    args.func(args.run)


if __name__ == '__main__':
    parse_args()



#!/usr/bin/env python2
# -*- coding: utf-8 -*-

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

import flyfingers

requisites = []

setup(
    name='flyfingers',
    version=flyfingers.__version__,
    description='Learn to type 10 fingers',
    scripts=['scripts/flyfingers'],
    author='Thanh Nguyen Tuong',
    author_email='ngtthanh1010@gmail.com',
    packages=['flyfingers'],
    url='https://github.com/swdream/flyfingers',
    license='MIT',
    classifiers=[
        'Environment :: Console',
        'Topic :: Terminals :: Terminal Emulators/X Terminals',
    ],
)
